"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const icons_1 = require("./icons");
const logger_1 = require("./utils/logger");
const THEME_SETTING = {
    colors: {
        brand: '#007AFF',
        grey: '#999999',
        darkGrey: '#666666'
    },
    spacing: {
        tiny: 4
    }
};
const SearchBarComponent = ({ searchToolContainerStyle, onActiveSearch, onSubmitSearch, clearButton = true, customIcon, iconStyle, inputProps, inputTextStyle, buttonStyle, buttonText = 'Search', buttonTextStyle, inputContainerStyle, inputActiveColor, inputInactiveColor }) => {
    const [inputTextActive, setInputTextActive] = (0, react_1.useState)(false);
    const [inputValue, setInputValue] = (0, react_1.useState)('');
    let textInputRef = (0, react_1.useRef)();
    let shouldClearButtonShow = (0, react_1.useRef)(false);
    const onSubmit = () => {
        var _a;
        (0, logger_1.logInfo)('onSubmit');
        shouldClearButtonShow.current = false;
        onSubmitSearch(inputValue);
        react_native_1.Keyboard.dismiss();
        (_a = textInputRef.current) === null || _a === void 0 ? void 0 : _a.blur();
    };
    const onChange = (e) => {
        (0, logger_1.logInfo)('onChange');
        setInputValue(e.nativeEvent.text);
    };
    const onLayout = (e) => {
        (0, logger_1.logInfo)('onLayout', e);
    };
    const onFocus = (0, react_1.useCallback)(() => {
        shouldClearButtonShow.current = true;
        setInputTextActive(true);
        onActiveSearch(true);
    }, []);
    const onBlur = (0, react_1.useCallback)(() => {
        shouldClearButtonShow.current = false;
        setInputTextActive(false);
        onActiveSearch(false);
    }, []);
    return (<react_native_1.View style={[styles.searchToolContainer(), searchToolContainerStyle]}>
      <react_native_1.View style={[
            styles.inputContainerStyle(),
            {
                borderColor: inputTextActive
                    ? inputActiveColor !== null && inputActiveColor !== void 0 ? inputActiveColor : THEME_SETTING.colors.brand
                    : inputInactiveColor !== null && inputInactiveColor !== void 0 ? inputInactiveColor : THEME_SETTING.colors.grey
            },
            inputContainerStyle
        ]}>
        {customIcon ? (customIcon) : (<icons_1.SearchIcon width={20} height={20} stroke={THEME_SETTING.colors.grey} strokeWidth={1.8} style={[styles.iconStyle(), iconStyle]}/>)}
        <react_native_1.TextInput style={[
            styles.searchBarInput(),
            inputTextStyle
        ]} value={inputValue} onSubmitEditing={onSubmit} onChange={onChange} onFocus={onFocus} onBlur={onBlur} placeholder="Please enter your search" placeholderTextColor={THEME_SETTING.colors.grey} ref={(ref) => (textInputRef = ref)} {...inputProps}/>
        {clearButton && shouldClearButtonShow.current && (<react_native_1.Pressable onPress={() => setInputValue('')}>
            <icons_1.ClearIcon style={{
                marginHorizontal: 5
            }} width={15} height={15} stroke={THEME_SETTING.colors.grey} strokeWidth={1.8}/>
          </react_native_1.Pressable>)}
      </react_native_1.View>
      <react_native_1.Pressable onLayout={onLayout} onPress={onSubmit} style={[styles.searchButton(), buttonStyle]}>
        <react_native_1.Text style={[styles.searchButtonText(), buttonTextStyle]}>{buttonText}</react_native_1.Text>
      </react_native_1.Pressable>
    </react_native_1.View>);
};
const SearchBar = (0, react_1.memo)(SearchBarComponent);
const styles = {
    searchToolContainer: () => ({
        width: '100%',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'flex-start',
        height: 30
    }),
    inputContainerStyle: () => ({
        height: '100%',
        borderWidth: 1,
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center'
    }),
    searchBarInput: () => ({
        fontSize: 16,
        height: '100%',
        lineHeight: 22,
        fontWeight: 'normal',
        color: THEME_SETTING.colors.darkGrey,
        padding: THEME_SETTING.spacing.tiny,
        flex: 1
    }),
    searchButton: () => ({
        borderRadius: 5,
        marginLeft: THEME_SETTING.spacing.tiny,
        flexDirection: 'row',
        height: '100%',
        alignItems: 'center',
        justifyContent: 'space-between',
        paddingVertical: 5,
        paddingHorizontal: 10,
        backgroundColor: THEME_SETTING.colors.brand
    }),
    searchButtonText: () => ({
        fontSize: 14,
        lineHeight: 22,
        fontWeight: 'bold',
        color: '#f5f3ff'
    }),
    iconStyle: () => ({
        marginRight: 10,
        marginLeft: 5
    })
};
exports.default = SearchBar;
